# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from chat_server_connector.models.contact import Contact  # noqa: E501

class TestContact(unittest.TestCase):
    """Contact unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Contact:
        """Test Contact
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Contact`
        """
        model = Contact()  # noqa: E501
        if include_optional:
            return Contact(
                id = 56,
                role = 1,
                nickname = '',
                personal_description = '',
                first_name = '',
                last_name = '',
                avatar_id = '',
                is_online = True,
                address = chat_server_connector.models.contact_address.ContactAddress(
                    city = '', 
                    country = '', 
                    street_and_number = '', 
                    company = '', 
                    postal_code = '', ),
                phone_number = '',
                is_public_email = True,
                is_public_phone_number = True,
                is_public_city = True,
                is_public_country = True,
                email = ''
            )
        else:
            return Contact(
                id = 56,
                role = 1,
        )
        """

    def testContact(self):
        """Test Contact"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
